==> kolourpaint_4.13.0.orig.tar.xz: kolourpaint-4.13.0/commands/imagelib/transforms/kpTransformRotateCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpTransformRotateCommand_H
#define kpTransformRotateCommand_H


#include <kpColor.h>
#include <kpCommand.h>
#include <kpImage.h>


class kpAbstractImageSelection;


class kpTransformRotateCommand : public kpCommand
{
public:
    kpTransformRotateCommand (bool actOnSelection,
        double angle,  // 0 <= angle < 360 (clockwise)
        kpCommandEnvironment *environ);
    virtual ~kpTransformRotateCommand ();

    virtual QString name () const;

    virtual SizeType size () const;

    virtual void execute ();
    virtual void unexecute ();

private:
    bool m_actOnSelection;
    double m_angle;

    kpColor m_backgroundColor;

    bool m_losslessRotation;
    kpImage m_oldImage;
    kpAbstractImageSelection *m_oldSelectionPtr;
};


#endif  // kpTransformRotateCommand_H

==> kolourpaint_21.12.3.orig.tar.xz: kolourpaint-21.12.3/commands/imagelib/transforms/kpTransformRotateCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpTransformRotateCommand_H
#define kpTransformRotateCommand_H


#include "imagelib/kpColor.h"
#include "commands/kpCommand.h"
#include "imagelib/kpImage.h"


class kpAbstractImageSelection;


class kpTransformRotateCommand : public kpCommand
{
public:
    kpTransformRotateCommand (bool actOnSelection,
        double angle,  // 0 <= angle < 360 (clockwise)
        kpCommandEnvironment *environ);
    ~kpTransformRotateCommand () override;

    QString name () const override;

    SizeType size () const override;

    void execute () override;
    void unexecute () override;

private:
    bool m_actOnSelection;
    double m_angle;

    kpColor m_backgroundColor;

    bool m_losslessRotation;
    kpImage m_oldImage;
    kpAbstractImageSelection *m_oldSelectionPtr;
};


#endif  // kpTransformRotateCommand_H
